@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2016 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Stream
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2016 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Stream
  */
@@ -26,8 +26,10 @@ class Horde_Stream_Temp extends Horde_Stream
      * Constructor.
      *
      * @param array $opts  Additional configuration options:
+     * <pre>
      *   - max_memory: (integer) The maximum amount of memory to allocate to
      *                 the PHP temporary stream.
+     * </pre>
      *
      * @throws Horde_Stream_Exception
      */
@@ -42,8 +44,8 @@ class Horde_Stream_Temp extends Horde_Stream
     protected function _init()
     {
         $cmd = 'php://temp';
-        if (isset($opts['max_memory'])) {
-            $cmd .= '/maxmemory:' . intval($opts['max_memory']);
+        if (isset($this->_params['max_memory'])) {
+            $cmd .= '/maxmemory:' . intval($this->_params['max_memory']);
         }
 
         if (($this->stream = @fopen($cmd, 'r+')) === false) {
