@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2014-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category   Horde
- * @copyright  2014 Horde LLC
+ * @copyright  2014-2016 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Stream
  * @subpackage UnitTests
@@ -19,7 +19,7 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2014 Horde LLC
+ * @copyright  2014-2016 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Stream
@@ -40,4 +40,17 @@ class Horde_Stream_Stream_TempStringTest extends Horde_Stream_Stream_TestBase
         $this->assertFalse($ob->use_stream);
     }
 
+    public function testMaxMemory()
+    {
+        $ob = new Horde_Stream_TempString(array('max_memory' => 1));
+        $ob->add('abcdefg');
+        $this->assertTrue($ob->use_stream);
+        $this->assertEquals('abcdefg', $ob->__toString());
+
+        $ob = new Horde_Stream_TempString(array('max_memory' => 10));
+        $ob->add('abcd');
+        $this->assertFalse($ob->use_stream);
+        $this->assertEquals('abcd', $ob->__toString());
+    }
+
 }
